@@ -8,7 +8,7 @@ with 'Dist::Zilla::Role::PluginBundle::Easy',
 use namespace::clean;
 use Data::Section -setup;
 
-our $VERSION = '0.026';
+our $VERSION = '0.027';
 
 sub configure {
 	my $self = shift;
@@ -26,7 +26,7 @@ sub configure {
 	my %githubmeta_config = (issues => 1);
 	$githubmeta_config{user} = $user if length $user;
 	$self->add_plugins([GithubMeta => \%githubmeta_config]);
-	$self->add_plugins([ReadmeAnyFromPod => 'Readme_Github' => { type => 'pod', filename => 'README.pod', location => 'root' }]);
+	$self->add_plugins([ReadmeAnyFromPod => 'Readme_Github' => { type => 'pod', filename => 'README.pod', location => 'root', phase => 'release' }]);
 	$self->add_plugins([GenerateFile => 'Generate_Contrib' => { filename => 'CONTRIBUTING.md', content => [split /\n/, ${$self->section_data('CONTRIBUTING.md')}] }]);
 	$self->add_plugins('MetaConfig');
 	$self->add_plugins('MetaProvides::Package', 'Prereqs::FromCPANfile', 'Git::Contributors');
@@ -62,7 +62,8 @@ sub configure {
 	
 	$self->add_plugins(
 		['Git::GatherDir' => { exclude_filename => [@ignore_files, @from_build] }],
-		[CopyFilesFromBuild => { copy => \@from_build }]);
+		[Regenerate => { filenames => \@from_build }],
+		['Regenerate::AfterReleasers' => { plugins => ['@Author::DBOOK/Readme_Github'] }]);
 	# @Basic, with some modifications
 	$self->add_plugins(qw/PruneCruft ManifestSkip MetaYAML MetaJSON
 		License ReadmeAnyFromPod ExecDir ShareDir/);
@@ -101,6 +102,7 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
  type = pod
  filename = README.pod
  location = root
+ phase = release
  
  [GenerateFile / Generate_Contrib]
  filename = CONTRIBUTING.md
@@ -158,12 +160,14 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
  exclude_filename = META.json
  exclude_filename = Makefile.PL
  exclude_filename = Build.PL
- [CopyFilesFromBuild]
- copy = INSTALL
- copy = LICENSE
- copy = CONTRIBUTING.md
- copy = META.json
- copy = Makefile.PL
+ [Regenerate]
+ filename = INSTALL
+ filename = LICENSE
+ filename = CONTRIBUTING.md
+ filename = META.json
+ filename = Makefile.PL
+ [Regenerate::AfterReleasers]
+ plugin = Readme_Github
  [PruneCruft]
  [ManifestSkip]
  [MetaYAML]
@@ -187,6 +191,15 @@ the dist's prereqs, a C<Changes> populated for the current version (see
 L<Dist::Zilla::Plugin::NextRelease>), and a C<.gitignore> including
 C</Name-Of-Dist-*> but not C<Makefile.PL>/C<Build.PL> or C<META.json>.
 
+To faciliate building the distribution for testing or installation without
+L<Dist::Zilla>, and provide important information about the distribution in
+the repository, several files can be copied to the repository from the build
+by running L<dzil regenerate|Dist::Zilla::App::Command::regenerate>. These
+files are: C<CONTRIBUTING.md>, C<INSTALL>, C<LICENSE>,
+C<Makefile.PL>/C<Build.PL>, and C<META.json>. The file C<README.pod> will also
+be generated in the repository (but not the build) by C<dzil regenerate> and
+C<dzil release>.
+
 To test releasing, set the env var C<FAKE_RELEASE=1> to run everything except
 the upload to CPAN.
 
@@ -337,6 +350,7 @@ Once everything is installed, here are some dzil commands you might try:
 
     $ dzil build
     $ dzil test
+    $ dzil regenerate
 
 You can learn more about Dist::Zilla at http://dzil.org/
 
